==> celloracle-0.10.12.tar.gz: celloracle-0.10.12/README.md <==
# CellOracle
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/morris-lab/CellOracle/build_and_test)](https://github.com/morris-lab/CellOracle/actions/workflows/build_check.yml)
[![PyPI](https://img.shields.io/pypi/v/celloracle?color=blue)](https://pypi.org/project/celloracle/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/celloracle)](https://pypi.org/project/celloracle/)
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/celloracle)](https://pypi.org/project/celloracle/)
[![Downloads](https://static.pepy.tech/personalized-badge/celloracle?period=total&units=international_system&left_color=grey&right_color=orange&left_text=Downloads)](https://pepy.tech/project/celloracle)
[![Docker Pulls](https://img.shields.io/docker/pulls/kenjikamimoto126/celloracle_ubuntu?color=red)](https://hub.docker.com/r/kenjikamimoto126/celloracle_ubuntu)

CellOracle is a python library for in silico gene perturbation analyses using single-cell omics data and Gene Regulatory Network models.

For more information, please read our bioRxiv preprint: [CellOracle: Dissecting cell identity via network inference and in silico gene perturbation](https://www.biorxiv.org/content/10.1101/2020.02.17.947416v3).


### Documentation, Codes, and Tutorials
CellOracle documentation is available through the links below.

[Web documentation](https://morris-lab.github.io/CellOracle.documentation/)


### Questions and errors
If you have a question, error, bug, or problem, please use the [Github issue page](https://github.com/morris-lab/CellOracle/issues).

### Supported Species and reference genomes

- Human: ['hg38', 'hg19']
- Mouse: ['mm39', 'mm10', 'mm9']
- S.cerevisiae: ["sacCer2", "sacCer3"]
- Zebrafish: ["danRer7", "danRer10", "danRer11"]
- Xenopus: ["xenTro2", "xenTro3"]
- Rat: ["rn4", "rn5", "rn6"]
- Drosophila: ["dm3", "dm6"]
- C.elegans: ["ce6", "ce10"]
- Arabidopsis: ["TAIR10"]
- Chicken: ["galGal4", "galGal5", "galGal6"]
- Guinea Pig: ["Cavpor3.0"]

Please let us know through [Github issue page](https://github.com/morris-lab/CellOracle/issues) if you have a request for another reference genome.

### Changelog

Please go to [this page](https://morris-lab.github.io/CellOracle.documentation/changelog/index.html).

==> celloracle-0.10.15.tar.gz: celloracle-0.10.15/README.md <==
# CellOracle
[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/morris-lab/CellOracle/build_check.yml?branch=master)](https://github.com/morris-lab/CellOracle/actions/workflows/build_check.yml)
[![PyPI](https://img.shields.io/pypi/v/celloracle?color=blue)](https://pypi.org/project/celloracle/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/celloracle)](https://pypi.org/project/celloracle/)
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/celloracle)](https://pypi.org/project/celloracle/)
[![Downloads](https://static.pepy.tech/personalized-badge/celloracle?period=total&units=international_system&left_color=grey&right_color=orange&left_text=Downloads)](https://pepy.tech/project/celloracle)
[![Docker Pulls](https://img.shields.io/docker/pulls/kenjikamimoto126/celloracle_ubuntu?color=red)](https://hub.docker.com/r/kenjikamimoto126/celloracle_ubuntu)

CellOracle is a python library for in silico gene perturbation analyses using single-cell omics data and Gene Regulatory Network models.

For more information, please read our bioRxiv preprint: [CellOracle: Dissecting cell identity via network inference and in silico gene perturbation](https://www.biorxiv.org/content/10.1101/2020.02.17.947416v3).


### Documentation, Codes, and Tutorials
CellOracle documentation is available through the links below.

[Web documentation](https://morris-lab.github.io/CellOracle.documentation/)


### Questions and errors
If you have a question, error, bug, or problem, please use the [Github issue page](https://github.com/morris-lab/CellOracle/issues).

### Supported Species and reference genomes

- Human: ['hg38', 'hg19']
- Mouse: ['mm39', 'mm10', 'mm9']
- S.cerevisiae: ["sacCer2", "sacCer3"]
- Zebrafish: ["danRer7", "danRer10", "danRer11"]
- Xenopus tropicalis: ["xenTro2", "xenTro3"]
- Xenopus laevis: ["Xenopus_laevis_v10.1"]
- Rat: ["rn4", "rn5", "rn6"]
- Drosophila: ["dm3", "dm6"]
- C.elegans: ["ce6", "ce10"]
- Arabidopsis: ["TAIR10"]
- Chicken: ["galGal4", "galGal5", "galGal6"]
- Guinea Pig: ["Cavpor3.0"]

Please let us know through [Github issue page](https://github.com/morris-lab/CellOracle/issues) if you have a request for another reference genome.

### Changelog

Please go to [this page](https://morris-lab.github.io/CellOracle.documentation/changelog/index.html).
